import java.util.*;

/**
 * Server
 * This is the main control for the server.
 * It holds a collection of clients in the main room and
 * available games to connect to.
 * @author David Couvrette
 * @version 0.0 Zero Feature Release
 */
public class Server {
  
  // hashmap to store all the clients that are in the main server room
  private HashMap clients;
  // hashmap to store all the current games on this server
  private HashMap games;
  
  
  /**
   * Construct and initialize the server
   */
  public Server() {
    clients = new HashMap();
    games = new HashMap();
    ScanIncomingConnections scan = new ScanIncomingConnections(this);
    Thread t = new Thread(scan);
    t.start();
  }
  
  /**
   * Adds a new client to the set of current clients
   * Starts a new thread that waits for another client
   * @param c The new client that is joining the server
   */  
  public void addNewClient(Client newClient) {
    if (clients.containsKey(newClient.getUserName()))
      throw new IllegalArgumentException("That name is already taken");
    clients.put(newClient.getUserName(), newClient);
  }
  
  /**
   * Sends a message to all clients
   * @param message The message that is sent to every client
   */
  public void sendToAllClients(String message) {
    Collection col = clients.values();
    Iterator it = col.iterator();
    while(it.hasNext()) {
      Client c = (Client)it.next();
      c.sendMsg(message);
    }
  }
}
